/* includes/sys/sdt-config.h.  Generated from sdt-config.h.in by configure.

   This file just defines some autoconf-detected assembler capability flags.
*/

#define _SDT_ASM_SECTION_AUTOGROUP_SUPPORT 1
#define _SDT_ASM_SECTION_RETAIN_SUPPORT 0
